@@ -1,4 +1,4 @@
-# $Revision: #1 $$Date: 2005/04/28 $$Author: nautsw $
+# $Revision: #3 $$Date: 2005/08/31 $$Author: jd150722 $
 ######################################################################
 #
 # This program is Copyright 2003-2005 by Jeff Dutton.
@@ -21,12 +21,11 @@ package Parse::RandGen::Regexp;
 
 require 5.006_001;
 use Carp;
-use Parse::RandGen;
+use Parse::RandGen qw($Debug);
 use Data::Dumper; # FIX - debug only
 use YAPE::Regex;
 use strict;
-use vars qw(@ISA $Debug %_Yterm);
-$Debug = $Parse::RandGen::Debug;
+use vars qw(@ISA %_Yterm $Debug);
 @ISA = ('Parse::RandGen::Condition');
 
 sub _newDerived {
